function D3flatarrow(P,V,col)

% D3flatarrow(pos,vec,col),  plots a 3D vector, vec, originating at pos,
%                    in color col as a flat arrow.
%
% pos [3x1]           = the origin (position of tail end) of the vector.
% vec [3x1]           = the vector. 
% col      [3x1]    = a three letter string (e.g. 'blu') denoting the color of
%                       the vector as given by D3color. 
%                       Type D3color('DEF') to see all the color definitions.   
%
%                     (The last argument may be omitted.)

if nargin==0, help D3flatarrow; return; end

if nargin==2,
    col='red';
end

co=D3color(col);

s=0.10;
t=0.02;
si=size(V);

for j=1:si(2)
u=P(:,j); 
du=V(1:2,j);    
r=norm(V(:,j));
ll=norm(du);
if ll>0, 
    si=V(3,j)/r;
    cs=ll/r;
    a=[-du(2); du(1)];
    a=a/norm(a);
    b=du/norm(du);
    du=r*b;
    A=[0 0 -a(2); 0 0 a(1); a(2) -a(1) 0];
    Q=eye(3,3) +si*A +(1-cs)*A^2;
end
if ll==0,
    du=[V(3) 0]';
    si=1; 
    cs=0;
    a=[0; 1];
    b=r*[1; 0];
    A=[0 0 -1; 0 0 0; 1 0 0];
    Q=eye(3,3) +si*A +(1-cs)*A^2;
end
AR=[0*a a*t du-b*s+a*t du-b*s+a*s du du-s*b-s*a du-s*b-t*a -t*a 0*a];
AR=[AR; 0*AR(1,:)];
e=ones(1,9);
BA=u*e;
AR=BA+Q*AR;
patch(AR(1,:),AR(2,:),AR(3,:),0*AR(1,:),'FaceColor',co(j,:))
axis image
end
