function D3surface(sfunc,xrange,yrange,col,alpha)

% D3surface(FUNCSTRING,xrange,yrange,col), 
%                    plots a 3D space surface in color col given by
%                    the equation in the string FUNCSTRING containing an 
%                    equation in x and y, (assigned to z).%                    
%
% FUNCSTRING [string]   = for example, FUNCSTRING='z=sqrt(1-x.^2-y.^2);',
%                        displays a hemisphere.      
% xrange     [2x1]      = range for x. 
% yrange     [2x1]      = range for y. 
% col        [3x1]      = a three letter string (e.g. 'blu') denoting the color of
%                       the vector as given by D3color. 
%                       Type D3color('DEF') to see all the color definitions.   
%
% alpha      [1x1]      = a transparancy factor between 0 and 1 
%                               (0=transparant, 1=opaque)
% 
%                     (The last two arguments may be omitted.)

if nargin==0, help D3surface; return; end

if nargin==3,
    col='red';
    alpha=0.5;
end
if nargin==4
    alpha=0.5;
end

co=D3color(col);

xspan=linspace(xrange(1),xrange(2),20);
yspan=linspace(yrange(1),yrange(2),20);
[x,y]=meshgrid(xspan,yspan);
eval(sfunc);
z=real(z);
surf(x,y,z,'FaceColor',co,'CDataMapping','direct','EdgeColor','k','FaceAlpha',alpha);
