function D3vectorA(pos,a,col,LABEL)
%
% D3vector(pos,vec,col,LABEL),  plots a 3D vector, vec, originating at pos,
%                    in color col, and a label LABEL near the arrow head.
%
% pos [3x1]      = the origin (position of tail end) of the vector.
% vec [3x1]      = the vector. 
% col [3x1]      = a three letter string (e.g. 'blu') denoting the color of
%                   the vector as given by D3color. 
%                   Type D3color('DEF') to see all the color definitions.   
% LABEL [string] = the label, printed in white.
% 
% (The last or last two arguments may be omitted.)

if nargin==0, help D3vector; return; end
if (a(1)==0) & (a(2)==0), a(2)=0.0001; end

if nargin==2,
    col='red';
    LABEL='';
end
if nargin==3
    LABEL='';
end

co=D3color(col);

na=norm(a);
siz=0.2;

if na>siz,
th=acos(a(3)/na);
ax=[-a(2); a(1); 0];
if norm(ax)>0, ax=ax/norm(ax); end
A=cpmat(ax);
Q=eye(3,3) + sin(th)*A + (1-cos(th))*A^2;

Na=10;
r=siz/6;
t=0:2*pi/Na:2*pi;
c=cos(t); s=sin(t); z=0*t+1;
c=c'; s=s'; z=z';
F1=[r*c'; r*s'; 0*z'];
F2=[r*c'; r*s'; na*z'-siz];
F3=[siz*c'/3; siz*s'/3; na*z'-siz];
F4=[0*c'; 0*s'; na*z'];

F1=Q*F1; F2=Q*F2; F3=Q*F3; F4=Q*F4;

X=[F1(1,:); F2(1,:); F3(1,:); F4(1,:)];
Y=[F1(2,:); F2(2,:); F3(2,:); F4(2,:)];
Z=[F1(3,:); F2(3,:); F3(3,:); F4(3,:)];

X=X+pos(1);
Y=Y+pos(2);
Z=Z+pos(3);

%X=[r*c r*c siz*c/3 0*c];
%Y=[r*s r*s siz*s/3 0*s];
%Z=[0*z na*z-siz na*z-siz na*z];



surface(X,Y,Z,0*Z,'CDataMapping','direct','EdgeColor','none','Facecolor',co);
%surfl(X+pos(1),Y+pos(2),Z+pos(3),'cdata');
%shading flat;
%caxis([0 10])
%light;
%plot3(X(1,:),Y(1,:),Z(1,:),'k')
%plot3(X(2,:),Y(2,:),Z(2,:),'k')
%plot3(X(3,:),Y(3,:),Z(3,:),'k')
po=[X(4,1);Y(4,1);Z(4,1)];
po=po + 0.1*po/norm(po);
text(po(1),po(2),po(3),LABEL,'Color',[1 1 1]*0.2,'Fontsize',14)
axis image
end